==> mysql-8.0_8.0.19.orig.tar.gz: mysql-8.0.19/plugin/group_replication/libmysqlgcs/src/bindings/xcom/xcom/xcom_msg_queue.h <==
/* Copyright (c) 2015, 2018, Oracle and/or its affiliates. All rights reserved.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License, version 2.0,
   as published by the Free Software Foundation.

   This program is also distributed with certain software (including
   but not limited to OpenSSL) that is licensed under separate terms,
   as designated in a particular file or component or in included license
   documentation.  The authors of MySQL hereby grant you an additional
   permission to link the program and your derivative works with the
   separately licensed software that they have included with MySQL.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License, version 2.0, for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA */

#ifndef XCOM_MSG_QUEUE_H
#define XCOM_MSG_QUEUE_H

#include "plugin/group_replication/libmysqlgcs/src/bindings/xcom/xcom/simset.h"
#include "plugin/group_replication/libmysqlgcs/src/bindings/xcom/xcom/task.h"
#include "plugin/group_replication/libmysqlgcs/xdr_gen/xcom_vp.h"

#ifdef __cplusplus
extern "C" {
#endif

/* Helper struct used for putting messages in a queue */
struct msg_link {
  linkage l;
  pax_msg *p;
  node_no to;
};
typedef struct msg_link msg_link;

msg_link *msg_link_new(pax_msg *p, node_no to);
char *dbg_msg_link(msg_link *link);
void empty_link_free_list();
void empty_msg_channel(channel *c);
void empty_msg_list(linkage *l);
void init_link_list();
void msg_link_delete(msg_link **link_p);

#ifdef __cplusplus
}
#endif

#endif

==> mysql-8.0_8.0.28.orig.tar.gz: mysql-8.0.28/plugin/group_replication/libmysqlgcs/src/bindings/xcom/xcom/xcom_msg_queue.h <==
/* Copyright (c) 2015, 2021, Oracle and/or its affiliates.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License, version 2.0,
   as published by the Free Software Foundation.

   This program is also distributed with certain software (including
   but not limited to OpenSSL) that is licensed under separate terms,
   as designated in a particular file or component or in included license
   documentation.  The authors of MySQL hereby grant you an additional
   permission to link the program and your derivative works with the
   separately licensed software that they have included with MySQL.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License, version 2.0, for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA */

#ifndef XCOM_MSG_QUEUE_H
#define XCOM_MSG_QUEUE_H

#include "xcom/simset.h"
#include "xcom/task.h"
#include "xdr_gen/xcom_vp.h"

/* Helper struct used for putting messages in a queue */
struct msg_link {
  linkage l;
  pax_msg *p;
  node_no to;
};
typedef struct msg_link msg_link;

msg_link *msg_link_new(pax_msg *p, node_no to);
char *dbg_msg_link(msg_link *link);
void empty_link_free_list();
void empty_msg_channel(channel *c);
void empty_msg_list(linkage *l);
void init_link_list();
void msg_link_delete(msg_link **link_p);
void shrink_msg_list(linkage *l, int n);
void shrink_msg_channel(channel *c, int n);

#endif
